@@ -47,8 +47,10 @@ Changelog
 0.0.42: fix: fix email
 0.0.43: add: add support response status code
 0.0.44: add: add login support
+0.0.45: add: add module format support
+0.0.46: fix: fix setup.py
 """
 
 __title__ = "AKTools"
-__version__ = "0.0.44"
+__version__ = "0.0.46"
 __author__ = "AKFamily"
