@@ -9,7 +9,7 @@ import pandas as pd
 
 url = "http://127.0.0.1:8080/api/fund_em_lcx_rank"
 params = {
-    # "symbol": "850335.SI",
+    "symbol": "850335.SI",
 }
 r = requests.get(url, params=params)
 temp_df = pd.DataFrame.from_dict(r.json())
